# Azure Application Insights for Angular 4.x.x

[![npm version](https://badge.fury.io/js/angular4-appinsights.svg)](https://badge.fury.io/js/angular4-appinsights)
[![Known Vulnerabilities](https://snyk.io/test/github/wmitio/angular4-appinsights/badge.svg)](https://snyk.io/test/github/wmitio/angular4-appinsights)
[![CircleCI](https://circleci.com/gh/wmitio/angular4-appinsights.svg?style=shield)](https://circleci.com/gh/wmitio/angular4-appinsights)

This library provides an implementation of [Microsoft Azure Application Insights](https://azure.microsoft.com/services/application-insights/) for Angular 4.x.x applications. This library is not dependent on the Node.js SDK for Azure Application Insights, but obtains the script dynamically. For general information please refer to the official [Application Insights for Node.js](https://github.com/Microsoft/ApplicationInsights-node.js) project.

## Requirements

### Installation

```cmd
npm install angular4-appinsights
```

### Getting started

1. Create an Application Insights resource in Azure by following [these instructions](https://docs.microsoft.com/azure/application-insights/app-insights-overview).
2. Obtain the _Instrumentation Key_ (aka "ikey") from the resource you created in
   step 1. Later, you will use it in your scripts.
3. Add the package as a dependency to your Angular 4.x.x application by installing the package.
4. Initialize the service as described in the following section.

## Usage

There are multiple ways to initialize the service, the following steps describe how to create a _singleton_ service
within the core module of your angular app. You can use the configured service in any other module of your app after initialization.

__core.module.ts__

```tsc
import { NgModule, Optional, SkipSelf } from '@angular/core';
import { CommonModule } from '@angular/common';
import { AppInsightsService } from 'angular4-appinsights';

@NgModule({
    imports: [CommonModule],
    providers: [AppInsightsService]
})
export class CoreModule {
    constructor(@Optional() @SkipSelf() parentModule: CoreModule) {
        throwIfAlreadyLoaded(parentModule, 'CoreModule');
    }
}
```

**app.module.ts**

```tsc
import { NgModule }      from '@angular/core';
import { BrowserModule } from '@angular/platform-browser';

import { AppComponent }  from './app.component';
import { CoreModule }    from './core/core.module';

@NgModule({
  imports:      [ BrowserModule, CoreModule]
  declarations: [ AppComponent ],
  bootstrap:    [ AppComponent ]
})
export class AppModule { }
```

**app.component.ts**

```tsc
import { Component } from '@angular/core';
import { AppInsightsService } from 'angular4-appinsights';

@Component({
  selector: 'my-app',
  templateUrl: './app.component.html',
  styleUrls: ['./app.scss']
})
export class AppComponent implements OnInit {
    constructor(private aiService: AppInsightsService) { }

    ngOnInit() {
        // Initialize the App Insights Service
        this.aiService.init({ instrumentationKey: <ikey> });
    }
}
```

## Help and Issues

Please use GitHub issues if you need help or have issues using the library.
We welcome your feedback to continuously improve this library. :+1:

[Open an issue on GitHub](https://github.com/wmitio/angular4-appinsights/issues).

## License

This project is licensed under MIT. See [LICENSE](LICENSE) for details.

## Dependencies

* [ngx-window-token >= 0.0.3](https://github.com/maxisam/ngx-window-token) to inject window token
* @angular/core from [Angular >= 4.1.1](https://github.com/angular/angular) as peer dependency
