// Type definitions for angular4-appinsights version 0.1.1
// Project: angular4-appinsights
// Definitions by: Sven Maschek https://github.com/smk1085

export interface AppInsightsConfig {
    instrumentationKey: string;
    endpointUrl?: string;
    accountId?: string;
    sessionRenewalMs?: number;
    sessionExpirationMs?: number;
    maxBatchSizeInBytes?: number;
    maxBatchInterval?: number;
    enableDebug?: boolean;
    disableTelemetry?: boolean;
    verboseLogging?: boolean;
    samplingPercentage?: boolean;
    diagnosticLogInterval?: number;
    disableExceptionTracking?: boolean;
    disableAjaxTracking?: boolean;
    overridePageViewDuration?: boolean;
    maxAjaxCallsPerView?: number;
    isCookieUseDisabled?: boolean;
    cookieDomain?: string;
    disableFlushOnBeforeUnload?: boolean;
    enableSessionStorageBuffer?: boolean;
    isRetryDisabled?: boolean;
    url?: string;
    isStorageUseDisabled?: boolean;
    disableCorrelationHeaders?: boolean;
    isBeaconApiDisabled?: boolean;
}

export declare enum SeverityLevel {
    Verbose = 0,
    Information = 1,
    Warning = 2,
    Error = 3,
    Critical = 4
}

export declare class AppInsightsService {
    constructor(_window: Window);
    init(config?: AppInsightsConfig): void;
    trackPageView(name?: string, url?: string, properties?: any, measurements?: any, duration?: number): void;
    startTrackPage(name?: string): void;
    stopTrackPage(name?: string, url?: string, properties?: any, measurements?: any): void;
    trackEvent(name: string, properties?: any, measurements?: any): void;
    trackMetric(name: string, average: number, sampleCount?: number, min?: number, max?: number, properties?: any): void;
    trackException(exception: Error, handledAt?: string, properties?: any, measurements?: any, severityLevel?: SeverityLevel): void;
    trackTrace(message: string, properties?: any, measurements?: any): void;
    trackDependency(id: string, method: string, absoluteUrl: string, pathName: string, totalTime: number, success: boolean, resultCode: number): void;
    flush(): void;
    setAuthenticatedUserContext(authenticatedUserId: string, accountId?: string): void;
    clearAuthenticatedUserContext(): void;
    getConfig(): AppInsightsConfig;
}